ReconnectSettings

Struct ReconnectSettings 

pub struct ReconnectSettings { /* private fields */ }
Settings that can be updated before reconnecting to a server

Implementations

Source

impl ReconnectSettings

pub fn new() -> Self

pub fn address<T>(&mut self, address: T) -> &mut Self
where T: Into<String>,

Sets the URL that will be used when reconnecting to the server

pub fn auth(&mut self, auth: Value)

Sets the authentication data that will be send in the opening request

pub fn opening_header<T: Into<HeaderValue>, K: Into<String>>( &mut self, key: K, val: T, ) -> &mut Self

Adds an http header to a container that is going to completely replace opening headers on reconnect. If there are no headers set in ReconnectSettings, client will use headers initially set via the builder.