Module payload

Module payload 

Deprecated import since 0.3.0-alpha-2, use Event in the crate root instead. Defines the types of payload (binary or string), that could be sent or received.

Enums

Payload
A type which represents a payload in the socket.io context. A payload could either be of the type Payload::Binary, which holds data in the Bytes type that represents the payload or of the type Payload::String which holds a std::string::String. The enum is used for both representing data that’s send and data that’s received. The optional i32 field represents the ack ID if this payload requires acknowledgment from the server.
PayloadData
Payload的数据部分(不包含ack_id)