Deprecated import since 0.3.0-alpha-2, use Event in the crate root instead. Defines the events that could be sent or received.
Enums
- Close
Reason - A
CloseReasonis the payload of theEvent::Closeand specifies the reason for why it was fired. These are aligned with the official Socket.IO disconnect reasons, see https://socket.io/docs/v4/client-socket-instance/#disconnect - Event
- An
Eventinsocket.iocould either (Message,Error) or custom.