Payload

Enum Payload 

pub enum Payload {
    Binary(Bytes, Option<i32>),
    Text(Vec<Value>, Option<i32>),
    String(String, Option<i32>),
}
A type which represents a payload in the socket.io context. A payload could either be of the type Payload::Binary, which holds data in the Bytes type that represents the payload or of the type Payload::String which holds a std::string::String. The enum is used for both representing data that’s send and data that’s received. The optional i32 field represents the ack ID if this payload requires acknowledgment from the server.

Variants



Binary(Bytes, Option<i32>)



Text(Vec<Value>, Option<i32>)



String(String, Option<i32>)

👎Deprecated:

Use Payload::Text instead. Continue existing behavior with: Payload::from(String)

String that is sent as JSON if this is a JSON string, or as a raw string if it isn’t

Implementations

Source

impl Payload

pub fn with_ack_id<T: Into<Self>>(payload: T, ack_id: i32) -> Self

创建一个带ack_id的payload

pub fn ack_id(&self) -> Option<i32>

获取payload的ack_id

pub fn set_ack_id(&mut self, ack_id: Option<i32>)

设置payload的ack_id

pub fn data(&self) -> PayloadData<'_>

获取payload的数据部分(不包含ack_id)